@@ -330,7 +330,7 @@ class MSData:
         self.intensityBPC = self.intensityBPC / np.max(self.intensityBPC) * 100
 
 
-    def plotBPC(self, pltName, fontsize=20, dpi=300, figsize=(6, 4)):
+    def plotBPC(self, pltName, fontsize=20, dpi=300, figsize=(6, 4), aspect=2.0):
         """
         Function to plot BPC.
 
@@ -344,6 +344,8 @@ class MSData:
             Resolution of the plot.
         figsize: tuple
             Size of the plot.
+        aspect: float
+            Aspect ratio of the plot.
         """
 
         # check if BPC data is ready
@@ -352,6 +354,8 @@ class MSData:
 
         plt.figure(figsize=figsize, dpi=dpi)
         plt.plot(self.rtBPC, self.intensityBPC, color="black", linewidth=1)
+        # set aspect ratio
+        plt.gca().set_aspect(aspect)
         plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=5)
         plt.ylabel("Intensity, %", fontname='Arial', fontsize=fontsize, labelpad=5)
         plt.xticks(fontname='Arial', fontsize=fontsize)
